const STAGE_CONFIG = 'PRODUCTION';


function insertUmami() {
	const script = document.createElement('script');
	script.async = true;
	script.src = 'https://gaig-analytics.netlify.app/script.js';
	const umamiCode = 'cb392f8e-e4f9-4bc1-ac69-9e5c19be6436';
	script.setAttribute('data-website-id', umamiCode);

	try {
		document.body.appendChild(script);
	} catch (error) {
		console.log(error);
	}
}

let offeringOptions = {};
let channelUrl;

if (typeof window !== 'undefined') {
	channelUrl = window.location.href;
}

function waitForOptions() {
	const checkInterval = setInterval(() => {
		if (window?.options) {
			// console.log('options is now available', options);
			offeringOptions = options;
			// console.log('offeringOptions', offeringOptions);
			clearInterval(checkInterval); // Stop checking
		}
	}, 100); // Check every 100 milliseconds
}

try {
	document.addEventListener('DOMContentLoaded', () => {
		if (STAGE_CONFIG == 'PRODUCTION') {
			insertUmami();
		}
		waitForOptions();

	});
} catch (error) {
	console.log(error);
}

const formatPremiumForGA = (premium) => {
	const formattedPremium = parseFloat(premium.replace('$', '')).toFixed(2);
	return formattedPremium;
};

let currentView = '';

const config = {
	userEvents(e) {
		//
		if (window?.Buddy?.partnerUserEvents) {
			window.Buddy.partnerUserEvents(e);
		}
		//
		let attributionId = null
		if (typeof offeringOptions?.data?.policy?.meta?.attributionId !== 'undefined' && offeringOptions?.data?.policy?.meta?.attributionId !== null) {
			attributionId = offeringOptions?.data?.policy?.meta?.attributionId
		}
		if (STAGE_CONFIG != 'PRODUCTION') console.log('attributionID from userEvents', attributionId)
		//	
		const { data } = e;
		const { eventType } = e;
		//
		const dataToSend = {
			...data,
			event_category: 'user_event',
			attributionId: attributionId
		};
		//
		if (STAGE_CONFIG == 'PRODUCTION') {
			if (eventType === 'onViewChange') {
				//
				currentView = dataToSend.viewId;

				umami.track(e.eventType, { viewScreen: e.data.viewId, ion: offeringOptions?.ion, channelUrl, attributionId });

				gtag('event', 'screen_view', {
					...dataToSend,
					screen_name: dataToSend.viewId,
					app_name: 'Accident Insurance Offer Element',
					item_id: 'IND_ACCIDENT',
				});
				//
				switch (dataToSend.viewId) {
					case 'offerView':
						break;
					case 'knockoutStateView':
						break;
					case 'childInfoView':
						fbq('track', 'ViewContent');
						pintrk('track', 'pagevisit');
						break;
					case 'childSportSelectionView':
						fbq('track', 'ViewContent');
						pintrk('track', 'pagevisit');
						break;
					case 'childIndividualSportSelection':
						break;
					case 'policyDatesView':
						fbq('track', 'ViewContent');
						pintrk('track', 'pagevisit');
						break;
					case 'customerInfoView':
						break;
					case 'quickOfferView':
						break;
					case 'summary':
						break;
					case 'checkout':
						fbq('track', 'AddPaymentInfo');
						pintrk('track', 'pagevisit');
						break;
					case 'thanks':
						break;
					case 'quote-error-view':
						break;
				}
				return;
			}
			// add additional condition for quickofferview only
			if (eventType === 'onQuote' && currentView === 'quickOfferView') {

				console.log('add to cart fired', data);
				//
				gtag('event', 'add_to_cart', {
					currency: 'USD',
					value: data.pricing,
					items: [{
						item_id: 'IND_ACCIDENT',
						// item_name: "POMI",
						affiliation: 'POMI_WEBSITE',
						item_brand: 'POMI',
						// item_list_id: "POMI",
						// location_id: "POMI",
						price: data.pricing,
						quantity: 1
					}],
					attributionId: attributionId
				});
				//
				fbq('track', 'AddToCart');
				pintrk('track', 'addtocart', {
					value: data.pricing,
					order_quantity: 1,
					currency: 'USD'
				});
				return
			}
			//
			// built in GA event
			if (eventType === 'onCheckout' && data.checkoutStatus === 'start') {
				umami.track(e.eventType, {
					checkoutStatus: e.data.checkoutStatus, orderID: e.data.orderID, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'add_payment_info', {
					currency: 'USD',
					value: formatPremiumForGA(data.premium),
					payment_type: 'Credit Card',
					items: [{
						item_id: 'IND_ACCIDENT',
						// item_name: "POMI",
						affiliation: 'POMI_WEBSITE',
						item_brand: 'POMI',
						// item_list_id: "POMI",
						// location_id: "POMI",
						price: formatPremiumForGA(data.premium),
						quantity: 1
					}],
					attributionId: attributionId
				});
				gtag('event', 'begin_checkout', {
					...dataToSend,
					currency: 'USD',
					value: formatPremiumForGA(data.premium)
				});
				return;
			}
			// built in GA event
			if (eventType === 'onCheckout' && data.checkoutStatus === 'success') {
				//
				umami.track(e.eventType, {
					checkoutStatus: e.data.checkoutStatus, orderID: e.data.orderID, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'purchase', {
					transaction_id: dataToSend.orderID,
					value: formatPremiumForGA(data.premium),
					currency: 'USD',
					items: [{
						item_id: 'IND_ACCIDENT',
						// item_name: "POMI",
						affiliation: 'POMI_WEBSITE',
						item_brand: 'POMI',
						// item_list_id: "POMI",
						// location_id: "POMI",
						price: formatPremiumForGA(data.premium),
						quantity: 1
					}],
					attributionId: attributionId
				});
				//
				fbq('track', 'Purchase', {
					value: formatPremiumForGA(data.premium),
					currency: 'USD'
				});
				//
				pintrk('track', 'checkout', {
					value: formatPremiumForGA(data.premium),
					order_quantity: 1,
					currency: 'USD',
					event_id: 'eventId0001',
					product_ids: ['1414', '1415']
				});
				//
				return;
			}
			//
			// This tracks when quotes are made
			if (e.eventType == 'onQuote') {
				umami.track(e.eventType, { ion: offeringOptions?.ion, channelUrl, attributionId });
			}

			if (eventType === 'onCheckout' && data.checkoutStatus === 'error') {
				gtag('event', 'failed_checkout', {
					...dataToSend,
					currency: 'USD',
					value: formatPremiumForGA(data.premium),
					error_message: data.checkoutError,
				});
				umami.track(e.eventType, {
					checkoutStatus: e.data.checkoutStatus, orderID: e.data.orderID, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				return;
			}
			//
			if (eventType === 'onValidationError') {
				umami.track(e.eventType, {
					elementId: e.data.elementId, validationError: e.data.validationError, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'validation_error', dataToSend);
				return;
			}
			if (eventType === 'onExternalLink') {
				umami.track(e.eventType, { externalLinkUrl: e.data.externalLinkUrl, ion: offeringOptions?.ion, channelUrl, attributionId });
				gtag('event', 'external_link_click', dataToSend);
				return;
			}
			if (eventType === 'onCheckboxSelection') {
				umami.track(e.eventType, {
					elementId: e.data.elementId, checked: e.data.checked, value: e.data.value, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'checkbox_selection', dataToSend);
				return;
			}
			if (eventType === 'onRadioSelection') {
				umami.track(e.eventType, {
					elementId: e.data.elementId, value: e.data.value, ion: offeringOptions?.ion, channelUrl, attributionId
				});
				gtag('event', 'radio_selection', dataToSend);
				return;
			}
			// DEFAULT
			gtag('event', eventType, dataToSend);
		}
	},
	themeBase: {
		baseTheme: 'base',
		palette: 'base',
		overrides: {
			styles: {
				'.card': {
					'@media (max-width: 460px)': {
						padding: '1rem!important'
					}
				},
				'#offer-container': {
					maxWidth: '1060px',
					margin: '0 auto',
					minHeight: '400px'
				},
				'.progress-bar-container': {
					marginBottom: '2rem!important'
				},
				'#offerView-view-container': {
					width: '100%',
					marginTop: '2rem',
					'@media (max-width: 768px)': {
						marginTop: '0!important',
						display: 'flex',
						flexWrap: 'wrap',
					}
				},
				'#offerView-content-container-0': {
					width: '40%',
					float: 'left',
					paddingRight: '2rem',
					marginBottom: '6rem!important',
					display: 'flex',
					justifyContent: 'left',
					alignItems: 'center',
					'@media (min-width: 992px)': {
						justifyContent: 'center',
						alignItems: 'center',
						margin: 'auto',
					},
					'@media (max-width: 768px)': {
						justifyContent: 'center',
						alignItems: 'center',
						marginBottom: '1rem!important',
						marginTop: '0!important',
						margin: 'auto',
						width: 'auto',
						height: 'auto',
						maxWidth: '354px',
						maxHeight: '298px',
						minHeight: '198px',
						minWidth: '167px',
					}
				},
				'#checkout-content-container-0': {
					position: 'absolute',
					left: '2rem',
					width: '100px',
					height: '100px',
					display: 'inline-block',
					marginRight: '2rem',
					'@media (max-width: 985px)': {
						width: '15%',
						display: 'none'
					}
				},
				'#childInfoView-content-container-0': {
					position: 'absolute',
					left: '2rem',
					width: '100px',
					height: '100px',
					display: 'inline-block',
					marginRight: '2rem',
					'@media (max-width: 985px)': {
						display: 'none'
					},
				},
				'#policyDatesView-content-container-0': {
					position: 'absolute',
					left: '2rem',
					top: '1rem',
					width: '100px',
					height: '100px',
					display: 'inline-block',
					marginRight: '2rem',
					'@media (max-width: 985px)': {
						display: 'none'
					}
				},
				'#policyDatesView-content-container-2 > p': {
					fontSize: '12px!important',
					marginBottom: '1rem!important',
					marginTop: '0px!important'
				},
				'#policyDatesView-content-container-1 > p': {
					marginBottom: '0px!important'
				},
				'#childInfoView-view-container, #policyDatesView-view-container, #checkout-wrapper': {
					position: 'relative'
				},
				'#childIndividualSportSelection-content-container-7': {
					right: '0',
					width: '150px',
					height: '150px',
					bottom: '5%',
					'@media (max-width: 768px)': {
						display: 'none'
					}
				},
				'#childInfoView-content-container-3, #checkout-content-container-2': {
					right: '0',
					width: '100px',
					height: '100px',
					position: 'absolute',
					bottom: '5%',
					'@media (max-width: 985px)': {
						display: 'none'
					}
				},
				'#policyDatesView-content-container-10': {
					float: 'right',
					width: '100px',
					height: '100px',
					position: 'relative',
					bottom: '3rem',
					'@media (max-width: 985px)': {
						display: 'none'
					}
				},
				'#checkout-content-container-2': {
					right: '0',
					width: '100px',
					height: '100px',
					position: 'absolute',
					bottom: '60%',
					'@media (max-width: 768px)': {
						display: 'none'
					}
				},
				'#offerView-content-container-1 h2': {
					color: 'var(--color-primary)',
					fontWeight: 'bold!important',
					marginBottom: '0rem!important',
					'@media (max-width: 480px)': {
						fontSize: '1.75rem!important',
						lineHeight: '2rem!important',
					}
				},
				'#offerView-content-container-3 p > strong': {
					color: 'var(--color-primary)'
				},
				'#offerView-content-container-4': {
					width: '100%',
				},
				'#policy-guardianFirstName-field-container, #policy-guardianLastName-field-container, #customer-firstName-field-container, #customer-lastName-field-container': {
					width: '100%',
					marginTop: '1rem!important',
					'@media (min-width: 768px)': {
						maxWidth: '24%',
						minWidth: '24%',
						maxHeight: '173px',
						display: 'inline-grid',
						marginRight: '1%',
						marginTop: '0px!important'
					}
				},
				'#customerInfoView-content-container-1 > #customer-firstName-field-container, #customerInfoView-content-container-1 > #customer-lastName-field-container': {
					width: '100%',
					marginTop: '1rem!important',
					'@media (min-width: 768px)': {
						maxWidth: '49%',
						minWidth: '49%',
						maxHeight: 'unset',
						display: 'inline-grid',
						marginRight: '1%',
						marginTop: '0px!important'
					}
				},
				'#policy-guardianEmail-field-container, #policy-policyDetails-state-field-container, #customer-email-field-container': {
					width: '100%',
					marginTop: '1rem!important',
					'@media (min-width: 768px)': {
						maxWidth: '24%',
						minWidth: '24%',
						display: 'inline-grid',
						marginRight: '1%'
					}
				},
				'#customerInfoView-content-container-6 > #customer-email-field-container': {
					width: '100%',
					marginTop: '1rem!important',
					'@media (min-width: 768px)': {
						maxWidth: '49%',
						minWidth: '49%',
						display: 'inline-grid',
						marginRight: '1%'
					}
				},
				'#knockoutStateView-content-container-0 h2, #quote-error-view-content-container-0 h2, #insuranceReplacementView-content-container-0 h2': {
					fontSize: '50px!important'
				},
				'#knockoutStateView-content-container-1 p, #insuranceReplacementView-content-container-1 p': {
					marginBottom: '0'
				},
				'#knockoutStateView-content-container-1 > p, #knockoutStateView-content-container-2 > p, #insuranceReplacementView-content-container-1 p, #insuranceReplacementView-content-container-2 p, #quote-error-view-content-container-1 p, #quote-error-view-content-container-2 p, #quote-error-view-content-container-3 p, #quote-error-view-content-container-4 p': {
					color: '#333333!important',
					marginTop: '0px!important',
					marginBottom: '1px!important'
				},
				'#knockoutStateView-content-container-3, #quote-error-view-content-container-5, #insuranceReplacementView-content-container-3': {
					width: '300px',
					height: 'auto'
				},
				'#offerView-content-container-1 h2, #offerView-content-container-1 p > strong, #offerView-content-container-3 p >strong, #childInfoView-content-container-1 h2, #childInfoView-content-container-0 h2, #childSportSelectionView-content-container-0 h2, #policyDatesView-content-container-0 h2, #policyDatesView-content-container-0 h2, #customerInfoView-content-container-0 h2': {
					color: 'var(--color-primary)'
				},
				'#childInfoView-content-container-1 h2, #childInfoView-content-container-1 p, #childSportSelectionView-content-container-0 h2, #childSportSelectionView-content-container-0 p, #customerInfoView-content-container-0 h2': {
					textAlign: 'center'
				},
				' #policy-utility-replaceCoverage-field-container .input-error': {
					display: 'none'
				},
				'#policy-guardianFirstName-field-container .input-error, #policy-guardianLastName-field-container .input-error, #policy-guardianEmail-field-container .input-error, #policy-policyDetails-state-field-container .input-error': {
					marginTop: '0px!important'
				},
				'#policyDatesView-content-container-4 > p, #policyDatesView-content-container-5 > p': {
					color: '#d62719!important'
				},
				// '#gaig-pomi-accident #policy-utility-accidentDuration, #gaig-pomi-accident label[for=policy-utility-accidentDuration], #gaig-pomi-sport-view #policy-utility-accidentDuration, #gaig-pomi-sport-view label[for=policy-utility-accidentDuration]': {
				// 	display: 'none'
				// },
				'#policy-utility-childFirstName-field-container, #policy-utility-childLastName-field-container, #policy-utility-childDob-field-container, #policy-utility-childGender-field-container, #policy-utility-childRelationship-field-container, #customer-firstName-field-container, #customer-lastName-field-container, #customer-address-city-field-container, #customer-address-state-field-container, #customer-address-postalCode-field-container, #customer-email-field-container, #customer-dob-field-container, #customer-phone-field-container, #policy-utility-beneficiaryFirstName-field-container, #policy-utility-beneficiaryLastName-field-container, #policy-utility-beneficiaryAddress-beneficiaryCity-field-container, #policy-utility-beneficiaryAddress-beneficiaryState-field-container, #policy-utility-beneficiaryAddress-beneficiaryPostalCode-field-container, #policy-startDate-field-container, #policy-endDate-field-container': {
					'@media (min-width: 768px)': {
						width: '49%',
						display: 'inline-grid',
						marginRight: '1%'
					}
				},

				'#policy-startDate-field-container, #policy-endDate-field-container': {
					'@media (min-width: 992px)': {
						maxWidth: '30%',
						minWidth: '30%',
						display: 'inline-grid',
						marginRight: '1%'
					}
				},
				'#policy-utility-waterSports-field-container': {
					display: 'flex!important',
					flexDirection: 'column!important',
					alignItems: 'center!important',
					marginLeft: '5%',
					marginRight: '5%'
				},
				'.button-primary': {
					textTransform: 'uppercase',
					transition: 'border-color .4s ease 0s,background-color .4s ease 0s',
					border: '2px solid var(--color-secondary)',
					borderRadius: '5rem !important',
					background: 'var(--color-secondary)',
					padding: '.75rem 1.125rem',
					fontWeight: 'bold',
					fontFamily: 'Poppins, sans-serif',
					fontSize: '13px',
					height: '40px',
					color: '#FFFFFF',
					marginTop: '2rem',
					bottom: '0',
					'&:hover': {
						background: '#FFFFFF',
						color: 'var(--color-primary)'
					},
					'@media (min-width: 768px)': {
						minWidth: 'unset'
					}
				},
				'.button-secondary': {
					textTransform: 'uppercase',
					transition: 'border-color .4s ease 0s,background-color .4s ease 0s',
					border: '2px solid var(--color-secondary)',
					borderRadius: '5rem !important',
					background: 'var(--color-secondary)',
					padding: '.75rem 1.125rem',
					fontWeight: 'bold',
					fontFamily: 'Poppins, sans-serif',
					fontSize: '13px',
					lineHeight: '0px!important',
					marginTop: '2rem!important',
					height: '40px',
					textAlign: 'center',
					color: '#FFFFFF',
					'&:hover': {
						background: '#FFFFFF',
						color: 'var(--color-primary)'
					},
					'@media (min-width: 768px)': {
						minWidth: 'unset'
					}
				},
				button: {
					textTransform: 'uppercase',
					backgroundColor: '#f3f6f9',
					fontWeight: 'bold',
					fontSize: '16px',
					lineHeight: '1',
					padding: '.75rem 1.125rem',
					color: '#fff',
					transition: 'background-color .4s ease 0s',
					borderRadius: '5rem'
				},
				'#childInfoView-content-container-0 h2, #policyDatesView-content-container-0 h2': {
					textAlign: 'center'
				},
				'#gaig-pomi-accident #policyDatesView-view-container, #gaig-pomi-accident #childSportSelectionView-view-container, #gaig-pomi-accident #childIndividualSportSelection-view-container, #gaig-pomi-sport-view #policyDatesView-view-container, #gaig-pomi-sport-view #childSportSelectionView-view-container': {
					textAlign: 'center',
					alignItems: 'center'
				},
				'#quickOfferView-view-title, #policy-utility-singleSports-required-asterisk, #policy-utility-manuallyEnterAddress-field-container > label, #policy-utility-footballSports-field-container > .input-error, #policy-utility-baseballSports-field-container > .input-error, #policy-utility-waterSports-field-container > .input-error, #policy-utility-winterSports-field-container > .input-error, #policy-utility-trackAndFieldSports-field-container > .input-error, #policy-utility-otherSports-field-container > .input-error, #policy-sportErrorMessage-field-container > label, #policy-sportErrorMessage-field-container > input, #powered-by-buddy-container': {
					display: 'none'
				},
				'#quickOfferView-content-container-1': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/quoteImg.png")',
					backgroundRepeat: 'no-repeat',
					backgroundSize: 'contain',
					content: "''",
					width: '350px',
					height: '350px',
					float: 'left',
					paddingLeft: '10px',
					display: 'inline-block',
					justifyContent: 'center',
					alignItems: 'center',
					textAlign: 'center',
					marginTop: '1rem',
					'@media (max-width: 768px)': {
						width: '300px',
						height: '250px',
						justifyContent: 'center',
						alignItems: 'center',
						margin: 'auto 1rem'
					}
				},
				'#quickOfferView-content-container-1 h2': {
					marginTop: '110px',
					marginRight: '6rem',
					textAlign: 'center',
					color: '#FFFFFF!important',
					fontSize: '65px!important',
					fontWeight: 'bold!important',
					fontFamily: 'Poppins, sans-serif',
					'@media (max-width: 768px)': {
						marginTop: '90px',
						marginRight: '5rem',
						textAlign: 'center',
						color: '#FFFFFF!important',
						fontSize: '55px!important',
						fontWeight: 'bold!important'
					}
				},
				'#quickOfferView-content-container-1 p': {
					color: '#FFFFFF!important',
					textAlign: 'left',
					marginTop: '120px',
					marginLeft: '1.5rem',
					fontSize: '12px!important',
					'@media (max-width: 768px)': {
						fontSize: '12px!important',
						marginLeft: '.5rem',
						marginTop: '140px'
					},
					'@media (max-width: 410px)': {
						marginLeft: '1.1rem',
						fontSize: '10px!important'
					},
				},
				'#quickOfferView-content-container-0 h2': {
					marginTop: '100px',
					marginLeft: '3rem',
					marginRight: '2rem',
					textAlign: 'left',
					lineHeight: '3rem!important',
					'@media (max-width: 768px)': {
						marginLeft: '0rem!important',
						marginRight: '0rem!important',
						textAlign: 'center',
						fontSize: '30px!important',
						marginTop: '2rem'
					}
				},
				'#quote-price-label-name, #quote-price-label-amount': {
					display: 'none'
				},
				'#policy-childLeagueTitle-field-container input': {
					display: 'none'
				},
				'#quickOfferView-view-container': {
					width: '100%',
					justifyContent: 'center',
					alignItems: 'center',
					'@media (max-width: 768px)': {
						display: 'flex',
						flexWrap: 'wrap'
					}
				},
				'#quickOfferView-content-container-0': {
					width: '49%',
					float: 'left',
					paddingRight: '20px',
					display: 'flex',
					justifyContent: 'center',
					alignItems: 'center',
					textAlign: 'center',
					marginBottom: '4rem!important',
					'@media (max-width: 768px)': {
						width: '100%',
						marginBottom: '0px!important'
					}
				},
				table: {
					borderCollapse: 'collapse',
					margin: '0 auto',
					marginBottom: '.5rem',
					padding: '.25rem',
					minWidth: '90%',
					width: '90%',
					tableLayout: 'inherit',
					fontColor: 'black',
					'@media (max-width: 600px)': {
						border: 0
					}
				},
				'#summary-content-container-2 > table > thead > tr > th:nth-child(2), #summary-content-container-4 > table > thead > tr > th:nth-child(2), #summary-content-container-6 > table > thead > tr > th:nth-child(2)': {
					'@media (max-width: 600px)': {
						display: 'flex',
						justifyContent: 'space-between',
						'font-size': '.8em'
					}

				},
				'#quickOfferView-content-container-2 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Accident & Medical'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-2 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Dental'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-2 > table > tbody > tr:nth-child(3) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Accidental Death & Dismemberment'",
						display: 'block',
						'font-size': '1.5em',
						color: 'var(--color-primary)'
					}
				},
				'#quickOfferView-content-container-2 > table > tbody > tr:nth-child(1) > td:nth-child(3):before, #quickOfferView-content-container-2 > table > tbody > tr:nth-child(2) > td:nth-child(3):before, #quickOfferView-content-container-2 > table > tbody > tr:nth-child(3) > td:nth-child(3):before': {
					'@media (max-width: 600px)': {
						content: "'Coverage Information'"
					}
				},
				'#summary-content-container-1,#summary-content-container-2, #summary-content-container-3, #summary-content-container-4, #summary-content-container-5, #summary-content-container-6, #summary-content-container-7': {
					table: {
						borderCollapse: 'collapse',
						margin: '0 auto',
						marginBottom: '.5rem',
						padding: '.25rem',
						minWidth: '90%',
						width: '90%',
						tableLayout: 'inherit',
						fontColor: 'black',
						'@media (max-width: 600px)': {
							border: 0,
							width: '100%'
						}
					},
					caption: {
						fontSize: '1.5em',
						margin: '.5em 0 .75em',
						'@media (max-width: 600px)': {
							border: 0
						}
					},
					'table tr': {
						backgroundColor: '#fff',
						border: '1px solid #ddd',
						'@media (max-width: 600px)': {
							display: 'block'
						}
					},
					'table th': {
						fontSize: '.95em',
						'@media (max-width: 600px)': {}
					},
					'table th, table td': {
						padding: '.625em',
						'@media (max-width: 600px)': {}
					},
					'table td': {
						'@media (max-width: 600px)': {
							borderBottom: '1px solid #ddd',
							display: 'block',
							fontSize: '.8em',
							textAlign: 'right',
							minHeight: '35px'
						}
					},
					'thead > tr > th:first-child': {
						'@media (max-width: 600px)': {
							display: 'none'
						}
					},
					'tbody > tr > td:first-child': {
						'@media (max-width: 600px)': {
							display: 'none'
						}
					},
					'table > tbody > tr > td:nth-child(2), thead > tr > th:nth-child(2)': {
						'@media (max-width: 600px)': { width: '100%!important' }
					},
					'tbody > tr > td:last-child': {
						'@media (max-width: 600px)': {
							paddingRight: '.5rem',
							textAlign: 'right'
						}
					},
					'td:before, th:before': {
						'@media (max-width: 600px)': {
							float: 'left',
							fontWeight: 'bold',
							textTransform: 'uppercase',
							paddingRight: '.5rem'
						}
					},
				},
				'#summary-content-container-1, #summary-content-container-3, #summary-content-container-5': {
					'thead > tr > th:first-child': {
						'@media (max-width: 600px)': {
							display: 'block'
						}
					},
				},
				'#quickOfferView-content-container-2': {
					table: {
						borderCollapse: 'collapse',
						margin: '0 auto',
						marginBottom: '.5rem',
						padding: '.25rem',
						minWidth: '90%',
						width: '90%',
						tableLayout: 'inherit',
						fontColor: 'black',
						'@media (max-width: 600px)': {
							border: 0,
							width: '100%'
						}
					},
					thead: {
						'@media (max-width: 600px)': {
							border: 'none',
							clip: 'rect(0 0 0 0)',
							height: '1px',
							margin: '-1px',
							overflow: 'hidden',
							padding: 0,
							position: 'absolute',
							width: '1px'
						}
					},
					caption: {
						fontSize: '1.5em',
						margin: '.5em 0 .75em',
						'@media (max-width: 600px)': {
							border: 0
						}
					},
					'table tr': {
						backgroundColor: '#fff',
						border: '1px solid #ddd',
						'@media (max-width: 600px)': {
							display: 'block'
						}
					},
					'table th': {
						fontSize: '.95em',
						'@media (max-width: 600px)': {}
					},
					'table th, table td': {
						padding: '.625em',
						// textAlign: 'center',
						'@media (max-width: 600px)': {}
					},
					'table td': {
						'@media (max-width: 600px)': {
							borderBottom: '1px solid #ddd',
							display: 'block',
							fontSize: '.8em',
							textAlign: 'left',
							minHeight: '35px'
						}
					},
					'thead > tr > th:first-child': {
						'@media (max-width: 600px)': {
							display: 'none'
						}
					},
					'tbody > tr > td:first-child': {
						'@media (max-width: 600px)': {
							display: 'none'
						}
					},
					'table > tbody > tr > td:nth-child(2), thead > tr > th:nth-child(2)': {
						'@media (max-width: 600px)': { width: '100%!important' }
					},
					'tbody > tr > td:last-child': {
						'@media (max-width: 600px)': {
							paddingRight: '.5rem',
							textAlign: 'left'
						}
					},
					'td:before, th:before': {
						'@media (max-width: 600px)': {
							display: 'block',
							fontWeight: 'bold',
							textTransform: 'uppercase',
							paddingRight: '.5rem'
						}
					},
				},
				'#summary-content-container-2 > table > thead > tr > th:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Name'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'DOB'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Relationship to Child'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(3) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Gender'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(4) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Sport'"
					}
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(5) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'League/Team'"
					}
				},
				'#summary-content-container-4 > table > thead > tr > th:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Name'"
					}
				},
				'#summary-content-container-4 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Address'"
					}
				},
				'#summary-content-container-4 > table > tbody > tr:nth-child(2) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Phone'"
					}
				},
				'#summary-content-container-4 > table > tbody > tr:nth-child(3) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Email'"
					}
				},
				'#summary-content-container-6 > table > thead > tr > th:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Name'"
					}
				},
				'#summary-content-container-6 > table > tbody > tr:nth-child(1) > td:nth-child(2):before': {
					'@media (max-width: 600px)': {
						content: "'Address'"
					}
				},
				'#quickOfferView-content-container-2 > table > thead > tr > th': {
					backgroundColor: 'var(--color-primary)',
					color: '#FFF'
				},
				'#quickOfferView-content-container-2 > table': {
					maxWidth: 'none!important'
				},
				'#quickOfferView-content-container-2 > table > thead > tr > th > nth-child(1)': {
					paddingLeft: '0px!important'
				},
				'#summary-content-container-1 > table > thead > tr > th, #summary-content-container-3 > table > thead > tr > th, #summary-content-container-5 > table > thead > tr > th': {
					fontWeight: 'bold',
					color: '#FFF!important',
					paddingBottom: '1rem!important'
				},
				'#summary-content-container-1 > table > thead > tr, #summary-content-container-3 > table > thead > tr > th, #summary-content-container-5 > table > thead > tr > th': {
					backgroundColor: 'var(--color-primary)',
					color: '#FFF'
				},
				'#summary-content-container-0 > table > tbody > tr > td, #summary-content-container-2 > table > thead > tr > th, #summary-content-container-4 > table > thead > tr > th, #summary-content-container-2 > table > tbody > tr > td, #summary-content-container-4 > table > thead > tr > th, #summary-content-container-4 > table > tbody > tr > td, #summary-content-container-6 > table > thead > tr > th, #summary-content-container-6 > table > tbody > tr > td': {
					fontWeight: '400',
					textAlign: 'left',
					paddingTop: '.6rem',
					paddingBottom: '.6rem',
					backgroundColor: '#FFF!important',
					width: '50%'
				},
				'#summary-content-container-2 > table > thead > tr > th, #summary-content-container-4 > table > thead > tr > th, #summary-content-container-6 > table > thead > tr > th, #summary-content-container-2 > table > tbody > tr > td, #summary-content-container-4 > table > tbody > tr > td, #summary-content-container-6 > table > tbody > tr > td': {
					color: '#333333!important'
				},
				'#summary-content-container-2 > table > tbody > tr > td, #summary-content-container-2 > table > thead > tr > th, #summary-content-container-4 > table > tbody > tr:nth-child(1) > td:nth-child(2) > a, #summary-content-container-6 > table > thead > tr > th': {
					fontWeight: '400!important',
					backgroundColor: '#FFF!important'
				},
				'#summary-content-container-2, #summary-content-container-4, #summary-content-container-6': {
					marginTop: '-20px'
				},
				'#policy-electronicSignature-field-container .input-error, #policy-utility-electronicDisclosure-field-container .input-error, #policy-utility-electronicSignature-field-container > label, #policy-utility-electronicDisclosure-field-container > label': {
					display: 'none'
				},
				'#summary-content-container-2 > table > tbody > tr:nth-child(1), #summary-content-container-2 > table > tbody > tr:nth-child(3), #summary-content-container-4 > table > tbody > tr:nth-child(1), #summary-content-container-4 > table > tbody > tr:nth-child(3) #summary-content-container-6 > table > tbody > tr:nth-child(1)': {
					backgroundColor: '#FFF!important'
				},
				'#summary-content-container-0 > h3': {
					fontWeight: 'normal'
				},
				'#childSportSelectionView-content-container-0 > p': {
					color: '#333333!important',
					marginTop: '0px!important',
					marginBottom: '1px!important'
				},
				'#childSportSelectionView-content-container-0': {
					marginBottom: '2rem!important'
				},
				'#policy-utility-singleSports-radio-button-wrapper input[type=radio] + label': {
					color: 'var(--color-primary)',
					fontWeight: 'bold',
					height: '50px',
					width: '70px',
					fontSize: '10px',
					lineHeight: '1rem',
					margin: '1rem auto',
					'@media (min-width: 450px)': {
						fontSize: '12px',
						margin: '.5rem!important',
					},
					'@media (min-width: 540px)': {
						margin: '1rem!important',
					},
					'@media (min-width: 630px)': {
						margin: '1rem!important',
					},
					'@media (min-width: 760px)': {
						// height: '100px',
						// width: '100px',
						margin: '2rem!important',
						fontSize: '14px',
					},
					'@media (min-width: 930px)': {
						height: '100px',
						width: '130px',
						margin: '0rem!important',
					},
				},
				'#policy-utility-singleSports-field-container': {
					alignItems: 'center',
					textAlign: 'center',
					margin: '0 auto',
					display: 'flex',
					justifyContent: 'space-between',
					flexWrap: 'wrap',
					maxWidth: '80%',
					'@media (max-width: 630px)': {
						maxWidth: '90%',
					},
				},
				'#policy-utility-baseballSports-field-container, #policy-utility-footballSports-field-container, #policy-utility-trackAndFieldSports-field-container, #policy-utility-waterSports-field-container, #policy-utility-winterSports-field-container, #policy-utility-otherSports-field-container , #policy-childLeague-field-container': {
					alignItems: 'center',
					textAlign: 'center',
					width: '90%',
					margin: '2rem auto',
					flexDirection: 'column',
					display: 'flex'
				},
				'.radio-button-option-wrapper label[for=policy-utility-singleSports-baseball], .radio-button-option-wrapper label[for=policy-utility-singleSports-winterSports], .radio-button-option-wrapper label[for=policy-utility-singleSports-basketball], .radio-button-option-wrapper label[for=policy-utility-singleSports-cheer], .radio-button-option-wrapper label[for=policy-utility-singleSports-football], .radio-button-option-wrapper label[for=policy-utility-singleSports-gymnastics], .radio-button-option-wrapper label[for=policy-utility-singleSports-soccer], .radio-button-option-wrapper label[for=policy-utility-singleSports-softball], .radio-button-option-wrapper label[for=policy-utility-singleSports-trackAndField], .radio-button-option-wrapper label[for=policy-utility-singleSports-volleyball], .radio-button-option-wrapper label[for=policy-utility-singleSports-waterSports], .radio-button-option-wrapper label[for=policy-utility-singleSports-otherSports]': {
					marginLeft: '2px!important',
					marginRight: '.5rem!important',
				},
				'#policy-utility-baseballSports-field-container label': {
					textAlign: 'left!important'
				},
				'#policy-utility-singleSports-radio-button-wrapper input[type=radio]:hover + label': {
					color: 'var(--color-primary)',
					backgroundColor: '#FFF',
					fontWeight: 'bold'
				},
				'#policy-utility-singleSports-radio-button-wrapper input[type=radio]:checked:focus': {
					position: 'relative',
					display: 'block',
					backgroundRepeat: 'no-repeat',
					backgroundSize: 'contain',
					backgroundPosition: 'center',
					content: "''",
					height: '75px',
					textAlign: 'center'
				},
				'#policy-utility-singleSports-radio-button-wrapper input[type=radio]:checked:before + label': {
					color: 'var(--color-primary)',
					textAlign: 'center',
					fontWeight: 'bold'
				},
				'#policy-utility-singleSports-radio-button-wrapper input[type=radio]:checked + label': {
					color: 'var(--color-primary)',
					fontWeight: 'bold'
				},
				'#policy-utility-singleSports-radio-button-wrapper': {
					display: 'flex',
					flexWrap: 'wrap',
					justifyContent: 'center',
					alignItems: 'center',
					textAlign: 'center',
					lineHeight: 2,
					marginBottom: '1rem',
				},
				'label[for=policy-utility-singleSports]': {
					display: 'none'
				},
				'label[for=policy-utility-singleSports-baseball]::before, label[for=policy-utility-singleSports-basketball]::before, label[for=policy-utility-singleSports-cheer]::before, label[for=policy-utility-singleSports-football]::before, label[for=policy-utility-singleSports-gymnastics]::before, label[for=policy-utility-singleSports-soccer]::before, label[for=policy-utility-singleSports-softball]::before, label[for=policy-utility-singleSports-trackAndField]::before, label[for=policy-utility-singleSports-volleyball]::before, label[for=policy-utility-singleSports-waterSports]::before, label[for=policy-utility-singleSports-winterSports]::before, label[for=policy-utility-singleSports-otherSports]::before': {
					display: 'block',
					backgroundRepeat: 'no-repeat',
					backgroundSize: 'contain',
					backgroundPosition: 'center',
					content: "''",
					width: '75px',
					height: '75px',
					textAlign: 'center',
					marginLeft: 'auto',
					marginRight: 'auto'
				},
				'.radio-button-option-wrapper': {
					marginBottom: '2rem',
				},
				'#policy-utility-singleSports-radio-button-wrapper .radio-button, #policy-utility-mobilePhoneCheckBox-field-container > label': {
					display: 'none'
				},
				'#policyDatesView-content-container-6 > p, #policyDatesView-content-container-7 > p, #policyDatesView-content-container-8 > p, #customerInfoView-content-container-5 > p': {
					color: '#D62719!important'
				},
				'#policyDatesView-content-container-7 > p': {
					marginBottom: '0rem!important'
				},
				'#policyDatesView-content-container-8 > p': {
					marginTop: '0rem!important',
				},
				'#policy-utility-childAgeNumber-field-container, #policy-utility-startDateBoolValue-field-container, #policy-utility-accidentDuration-field-container': {
					display: 'none',
					'.input-error': {
						display: 'none'
					}
				},
				'#policy-utility-electronicDisclosure-field-container': {
					marginTop: '2rem'
				},
				'label[for=policy-utility-singleSports-baseball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_baseball_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-baseball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_baseball_on.png")'
				},
				'label[for=policy-utility-singleSports-basketball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_basketball_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-basketball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_basketball_on.png")'
				},
				'label[for=policy-utility-singleSports-cheer]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_cheer_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-cheer]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_cheer_on.png")'
				},
				'label[for=policy-utility-singleSports-football]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_football_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-football]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_football_on.png")'
				},
				'label[for=policy-utility-singleSports-gymnastics]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_gymnastics_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-gymnastics]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_gymnastics_on.png")'
				},
				'label[for=policy-utility-singleSports-soccer]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_soccer_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-soccer]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_soccer_on.png")'
				},
				'label[for=policy-utility-singleSports-softball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_softball_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-softball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_softball_on.png")'
				},
				'label[for=policy-utility-singleSports-trackAndField]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_trackfield_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-trackAndField]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_trackfield_on.png")'
				},
				'label[for=policy-utility-singleSports-volleyball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_volleyball_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-volleyball]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_volleyball_on.png")'
				},
				'label[for=policy-utility-singleSports-waterSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_watersports_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-waterSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_watersports_on.png")'
				},
				'label[for=policy-utility-singleSports-winterSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/wintersports_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-winterSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/wintersports_on.png")'
				},
				'label[for=policy-utility-singleSports-otherSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_othersports_off.png")'
				},
				'input[type=radio]:checked + label[for=policy-utility-singleSports-otherSports]::before': {
					backgroundImage: 'url("https://staging.embed.buddy.insure/gaig/pomi/icon_othersports_on.png")'
				},
				'.view-title': {
					marginTop: '3rem'
				},
				'#quote-price-label-container': {
					display: 'none'
				},
				'#policy-utility-mobilePhoneCheckBox-checkbox-wrapper > label': {
					color: 'rgba(10, 36, 45, 0.6)',
					fontSize: '14px'
				},
				'#checkout-content-container-1 h2': {
					lineHeight: '3rem!important'
				},
				'#thanks-view-container, #quote-error-view-view-container, #knockoutStateView-view-container, #insuranceReplacementView-view-container': {
					display: 'flex',
					flexDirection: 'column',
					justifyContent: 'center',
					alignItems: 'center',
					textAlign: 'center',
					color: '#333333!important',
					lineHeight: '1'
				},
				'#thanks-content-container-0 > h2, quote-error-view-view-title': {
					fontWeight: 'bold!important'
				},
				'#thanks-content-container-2 > p, #thanks-content-container-3 > p, #thanks-content-container-4 > p, #quote-error-view-content-container-1 > h3': {
					color: '#333333!important',
					marginTop: '0px!important',
					marginBottom: '1px!important'
				},
				'#thanks-content-container-1 > p > img': {
					width: '400px',
					height: 'auto',
					marginLeft: '7rem',
					'@media (max-width: 601px)': {
						marginLeft: 'auto',
						width: '80%'
					}
				},
				'#quote-error-view-content-container-0 > p > img': {
					width: '400px',
					height: 'auto'
				},
				'#offerView-content-container-0 > p > img': {
					'@media (max-width: 768px)': {
						marginTop: '0!important',
						marginBottom: '0!important'
					}
				},
				'#customerInfoView-content-container-10 > p': {
					marginBottom: '1rem'
				},
				'#checkout-view-container': {
					minHeight: '150px !important',
					display: 'flex',
					flexDirection: 'column',
					justifyContent: 'center',
					alignItems: 'center',
					textAlign: 'center',
					marginLeft: '10%',
					marginRight: '10%',
					'@media (max-width: 601px)': {
						marginLeft: '0',
						marginRight: '0'
					}
				},
				'#checkout-view-title': {
					display: 'none'
				},
				'.view-container': {
					marginTop: '0',
					minHeight: '350px'
				},
				body: {
					fontFamily: 'Poppins, sans-serif',
					fontSize: '16px',
					'@media (min-width: 768px)': {
						fontSize: '16px'
					},
					margin: '0 auto'
				},
				h2: {
					fontFamily: 'Poppins, sans-serif',
					fontWeight: '400!important',
					marginTop: '2rem',
					fontSize: '50px',
					color: 'var(--color-primary)!important',
					'@media (max-width: 768px)': {
						fontSize: '35px!important'
					},
					'@media (max-width: 450px)': {
						fontSize: '30px!important'
					}
				},
				h3: {
					fontFamily: 'Poppins, sans-serif',
					fontWeight: 'bold',
					fontSize: '30px',
					color: 'var(--color-primary)'
				}
			},
			colors: {
				primary: '#5C77DF',
				secondary: '#FF9A52',
				textPrimary: '#333333'
			},
			webFonts: [
				'https://fonts.googleapis.com/css2?family=Poppins:wght@400;700&display=swap'
			]
		}
	},
};
